@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -31,7 +31,7 @@ public:
     ~EnvironmentSettingsRulesPage();
     void setRules(const QString &rules);
 private:
-    EnvironmentPlainTextEdit *mPlainTextEdit = nullptr;
+    EnvironmentPlainTextEdit *mRichTextEdit = nullptr;
 };
 
 #endif // ENVIRONMENTSETTINGSRULESPAGE_H
